#include "fastdeploy/vision.h"

#ifdef WIN32
const char sep = '\\';
#else
const char sep = '/';
#endif

int main(int argc, char* argv[]) {
  std::string model_dir = std::string(argv[1]);
  std::string img_file = std::string(argv[2]);

  auto model_file = model_dir + sep + "model.pdmodel";
  auto params_file = model_dir + sep + "model.pdiparams";
  auto config_file = model_dir + sep + "infer_cfg.yml";
  auto model = fastdeploy::vision::detection::PicoDet(model_file, params_file,
                                                      config_file);
  if (!model.Initialized()) {
    std::cerr << "Failed to initialize." << std::endl;
    return -1;
  }

  // enable flycv
//  fastdeploy::vision::EnableFlyCV();

  auto im = cv::imread(img_file);

  // warmup
  std::cout << "warmup..." << std::endl;
  for (int i = 0; i < 20; ++i) {
    fastdeploy::vision::DetectionResult result;
    model.Predict(&im, &result);
  }

  // test
  fastdeploy::TimeCounter tc;
  tc.Start();
  for (int i = 0; i < 20; ++i) {
    fastdeploy::vision::DetectionResult result;
    model.Predict(&im, &result);
  }
  tc.End();
  std::cout << "Total time: " << tc.Duration() << std::endl;
  return 0;
}
